#!/usr/bin/perl -w

use Test::More 'no_plan';

package Catch;

sub TIEHANDLE {
    my($class, $var) = @_;
    return bless { var => $var }, $class;
}

sub PRINT  {
    my($self) = shift;
    ${'main::'.$self->{var}} .= join '', @_;
}

sub OPEN  {}    # XXX Hackery in case the user redirects
sub CLOSE {}    # XXX STDERR/STDOUT.  This is not the behavior we want.

sub READ {}
sub READLINE {}
sub GETC {}
sub BINMODE {}

my $Original_File = 'root/etc/e-smith/web/functions/remoteaccess';

package main;

# pre-5.8.0's warns aren't caught by a tied STDERR.
$SIG{__WARN__} = sub { $main::_STDERR_ .= join '', @_; };
tie *STDOUT, 'Catch', '_STDOUT_' or die $!;
tie *STDERR, 'Catch', '_STDERR_' or die $!;

{
    undef $main::_STDOUT_;
    undef $main::_STDERR_;
#line 36 root/etc/e-smith/web/functions/remoteaccess

use esmith::FormMagick::Tester;
use esmith::TestUtils;
use esmith::ConfigDB;
my $panel = 'remoteaccess';
my $panel_path = "/etc/e-smith/web/functions/".$panel;
my $ua = esmith::FormMagick::Tester->new();

is  (mode($panel_path), '4750',              "Check permissions on script");
ok  ($ua->get_panel($panel),            "ABOUT TO RUN L10N TESTS");
is  ($ua->{status}, 200,                "200 OK");
like($ua->{content}, qr/FORM_TITLE/,    "Saw untranslated form title");
ok  ($ua->set_language("en-us"),        "Set language to U.S. English");
ok  ($ua->get_panel($panel),            "Get panel");

is  ($ua->{status}, 200,                "200 OK");

like($ua->{content}, qr/remote access settings/, "Saw translated form title");

# Testing changes

ok  ($ua->get_panel($panel),            "Testing panel retrieval");
can_ok($ua, "field");
ok ($ua->{form}->find_input('FTPAccess'), 'Finding the FTPAccess field');
ok ($ua->{form}->find_input('sshAccess'), 'Finding the sshAccess field');
ok ($ua->{form}->find_input('sshPermitRootLogin'), 'Finding the sshPermitRootLogin field');
ok ($ua->{form}->find_input('sshTCPPort'), 'Finding the sshTCPPort field');
ok ($ua->{form}->find_input('pptpSessions'), 'Finding the pptpSessions field');
ok ($ua->{form}->find_input('sshPasswordAuthentication'), 'Finding the sshPasswordAuthentication field');
ok ($ua->{form}->find_input('FTPLimits'), 'Finding the FTPLimits field');
ok ($ua->{form}->find_input('TelnetAccess'), 'Finding the TelnetAccess field');

if (destruction_ok()) {
    $ua->field('FTPAccess' => 'private');
    $ua->field('sshAccess' => 'public');
    $ua->field('sshPermitRootLogin' => 'yes');
    $ua->field('sshTCPPort' => '22');
    $ua->field('pptpSessions' => '10');
    $ua->field('sshPasswordAuthentication' => 'yes');
    $ua->field('FTPLimits' => 'normal');
    $ua->field('TelnetAccess' => 'private');
}

ok  ($ua->click("Save"),                "Click Save");
is  ($ua->{status}, 200,                "200 OK");

like($ua->{content}, qr/settings have been saved/, "Saw validation messages");

# Gotta open this later, so we don't cache stale data
my $db = esmith::ConfigDB->open;

SKIP: 
{
    skip 9, "Unsafe!" unless destruction_ok();

    is($db->get('sshd')->prop('access'), 'public', "We have public ssh");
    is($db->get('sshd')->prop('PasswordAuthentication'), 'yes', "We have password auth");
    is($db->get('sshd')->prop('PermitRootLogin'), 'yes', "We have root login");
    is($db->get('sshd')->prop('TCPPort'), '22', "Got the right tcp port for ssh');    
    is($db->get('sshd')->prop('status'), 'enabled', "ssh is enabled");
    
    is ($db->get('ftp')->prop('access'), 'private', "ftp access is private");
    is ($db->get('ftp')->prop('accessLimits'), 'normal', "ftp access limits are normal");
    is ($db->get('pptpd')->prop('sessions') ,'10', "Got the right sesison count for pptp");
    is ($db->get('pptpd')->prop('status') ,'enabled', "pptp is enabled");
    is ($db->get('telnet')->prop('access'), 'private', "Private telnet turned on");
}


    undef $main::_STDOUT_;
    undef $main::_STDERR_;
}

